/*
	ef Add Child Joint v1.1 (20090226)
	Just adds a child joint positioned so the "length" and
	vector matches that of the parent. This is analog to 
	how child bones are created.
	
	v1.0 -Initial release.
	V1.1 -If a mesh is selected a new root joint is created.
		 -If more than one joints is selected, the last
		 selected joint receives a new child.
	
	Use at own risk. Feel free to modify.
	
	Dan Dulberger, evenflcw@yahoo.com
*/
@version 2.13
@warnings
@script generic
@name "ef Add Child Joint"

// global values go here

generic
{
	scene = Scene();
	time = scene.currenttime;

	items = scene.getSelect();
	if( !items || items[1].genus != MESH && items[1].genus != BONE ) {
		error("Bone drawing is available when editing objects or bones.");
		return;
	}
	
	parent = items[1];
	if( parent.genus == MESH )
		//if selected item is a mesh, create new joint chain.
		CommandInput("AddJoint");
	else {
		CommandInput("AddChildJoint");
		if( parent.parent.genus == MESH )
		//if selected item is the root joint, create a joint that is 1 meter long.
			Position(<0,0,1>);
		else
		//else, if selected item is any other joint, create a child joint with length and direction matching the selected.
			Position(parent.getPosition(time));
	}
}